==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetVoiceTemplateRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetVoiceTemplateRequest(
    templateName: __string,
    version: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest = {
    import GetVoiceTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
      .builder()
      .templateName(__string.unwrap(templateName): java.lang.String)
      .optionallyWith(
        version.map(value => __string.unwrap(value): java.lang.String)
      )(_.version)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetVoiceTemplateRequest.ReadOnly =
    zio.aws.pinpoint.model.GetVoiceTemplateRequest.wrap(buildAwsValue())
}
object GetVoiceTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetVoiceTemplateRequest =
      zio.aws.pinpoint.model
        .GetVoiceTemplateRequest(templateName, version.map(value => value))
    def templateName: __string
    def version: Option[__string]
    def getTemplateName: ZIO[Any, Nothing, __string] = ZIO.succeed(templateName)
    def getVersion: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("version", version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
  ) extends zio.aws.pinpoint.model.GetVoiceTemplateRequest.ReadOnly {
    override val templateName: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.templateName())
    override val version: Option[__string] = scala
      .Option(impl.version())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
  ): zio.aws.pinpoint.model.GetVoiceTemplateRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetVoiceTemplateRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetVoiceTemplateRequest(
    templateName: __string,
    version: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest = {
    import GetVoiceTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
      .builder()
      .templateName(templateName: java.lang.String)
      .optionallyWith(version.map(value => value: java.lang.String))(_.version)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetVoiceTemplateRequest.ReadOnly =
    zio.aws.pinpoint.model.GetVoiceTemplateRequest.wrap(buildAwsValue())
}
object GetVoiceTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetVoiceTemplateRequest =
      zio.aws.pinpoint.model
        .GetVoiceTemplateRequest(templateName, version.map(value => value))
    def templateName: __string
    def version: Optional[__string]
    def getTemplateName: ZIO[Any, Nothing, __string] = ZIO.succeed(templateName)
    def getVersion: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("version", version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
  ) extends zio.aws.pinpoint.model.GetVoiceTemplateRequest.ReadOnly {
    override val templateName: __string = impl.templateName(): __string
    override val version: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.version())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetVoiceTemplateRequest
  ): zio.aws.pinpoint.model.GetVoiceTemplateRequest.ReadOnly = new Wrapper(impl)
}
